Class: Google::Apis::AdvisorynotificationsV1::GoogleCloudAdvisorynotificationsV1Settings

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/advisorynotifications_v1/classes.rb,
lib/google/apis/advisorynotifications_v1/representations.rb,
lib/google/apis/advisorynotifications_v1/representations.rb

Overview

Settings for Advisory Notifications.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GoogleCloudAdvisorynotificationsV1Settings

Returns a new instance of GoogleCloudAdvisorynotificationsV1Settings.



278
279
280
# File 'lib/google/apis/advisorynotifications_v1/classes.rb', line 278

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#etagString

Required. Fingerprint for optimistic concurrency returned in Get requests. Must be provided for Update requests. If the value provided does not match the value known to the server, ABORTED will be thrown, and the client should retry the read-modify-write cycle. Corresponds to the JSON property etag

Returns:

  • (String)


262
263
264
# File 'lib/google/apis/advisorynotifications_v1/classes.rb', line 262

def etag
  @etag
end

#nameString

Identifier. The resource name of the settings to retrieve. Format: organizations/organization/locations/location/settings or projects/ projects/locations/location/settings. Corresponds to the JSON property name

Returns:

  • (String)


269
270
271
# File 'lib/google/apis/advisorynotifications_v1/classes.rb', line 269

def name
  @name
end

#notification_settingsHash<String,Google::Apis::AdvisorynotificationsV1::GoogleCloudAdvisorynotificationsV1NotificationSettings>

Required. Map of each notification type and its settings to get/set all settings at once. The server will validate the value for each notification type. Corresponds to the JSON property notificationSettings



276
277
278
# File 'lib/google/apis/advisorynotifications_v1/classes.rb', line 276

def notification_settings
  @notification_settings
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



283
284
285
286
287
# File 'lib/google/apis/advisorynotifications_v1/classes.rb', line 283

def update!(**args)
  @etag = args[:etag] if args.key?(:etag)
  @name = args[:name] if args.key?(:name)
  @notification_settings = args[:notification_settings] if args.key?(:notification_settings)
end